==> tine20-projects_2016.11.24.tar.bz2: Projects/js/Projects-lang-pt_BR-debug.js <==
/********************** tine translations of Projects**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Projects'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2015-12-03 17:17+0000\nLast-Translator: pschuele <p.schuele@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "%s's personal Projects"
: "%s's Projetos pessoais"

, "Manage shared project favorites"
: "Gerenciar favoritos em projetos compartilhados"

, "Create new shared project favorites"
: "Criar um novo favorito no projeto"

, "Project, Projects"
: [
  "Projeto"
 ,"Projetos"

]
, "Project list, Project lists"
: [
  "Lista do Projeto"
 ,"Listas de Projetos"

]
, "Project lists"
: "Listas de Projetos"

, "Quick Search"
: "Busca Rápida"

, "Title"
: "Título"

, "Number"
: "Número"

, "Description"
: "Descrição"

, "Status"
: "Situação"

, "Last Modified Time"
: "Hora da última modificação"

, "Last Modified By"
: "Modificado por"

, "Creation Time"
: "Data de Criação"

, "Created By"
: "Criado por"

, "Attendee"
: "Participante"

, "Role"
: "Perfil"

, "Enter description"
: "Digitar a Descrição"

, "Attendee Role"
: "Perfil do participante"

, "Please choose the Project to add the contacts to"
: "Selecione o Projeto onde serão adicionados os contatos"

, "Please select the attenders' role"
: "Selecione o perfil do participante"

, "Select Project"
: "Selecione o Projeto"

, "Select Role"
: "Selecione o Perfil"

, "Adding {0} Participants to project"
: "Adicionando {0} Participantes ao projeto"

, "Projects"
: "Projetos"

, "Search FAQ"
: ""

, "Tags"
: "Identificação"

, "All my projects"
: "Todos os meus projetos"

, "Default Favorite"
: "Valor Padrão"

, "The default favorite which is loaded on Projects startup"
: "Valor padrão que serão exibido no início do Projeto"

, "Project Status Available"
: "Situação de Projeto Disponível"

, "Possible Project status. Please note that additional project status might impact other Projects systems on export or syncronisation."
: "Situação de Projeto Possível.  Favor observar que uma situação adicional de projeto pode afetar sistemas de outros Projetos durante a exportação ou sincronização."

, "On hold"
: "Aguardando"

, "Completed"
: "Completo"

, "Cancelled"
: "Cancelado"

, "In process"
: "Processando"

, "Project Attendee Role Available"
: "Perfil Disponível para Participante do Projeto"

, "Possible Project attendee roles. Please note that additional project attendee roles might impact other Projects systems on export or syncronisation."
: "Perfis possíveis para participantes de projetos. Favor observar que um perfil adicional de um participante do projeto pode afetar sistemas de outros Projetos durante a exportação ou sincronização."

, "Coworker"
: "Colega de trabalho"

, "Responsible"
: "Responsável"

, "All my open projects"
: "Todos os meus projetos ativos"

, "My projects that I'm responsible for"
: "Projetos sob minha responsabilidade"

, "All my open projects that I am responsible for"
: "Todos os projetos abertos pelos quais sou responsável"

, "My waiting projects"
: "Meus projetos em exigência"

, "My projects that are on hold"
: "Meus projetos que estão retidos"

, "Project"
: "Projeto"

, "Project list"
: "Lista do Projeto"

}));

==> tine20-projects_2017.08.11.tar.bz2: Projects/js/Projects-lang-pt_BR-debug.js <==
/********************** tine translations of Projects**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Projects'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-11-29 13:08+0000\nLast-Translator: fgsl <flavio.lisboa@serpro.gov.br>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Projects"
: "Projetos"

, "Search FAQ"
: "Buscar FAQ"

, "Tags"
: "Etiquetas"

, "Number"
: "Número"

, "Title"
: "Título"

, "Status"
: "Situação"

, "Project, Projects"
: [
  "Projeto"
 ,"Projetos"

]
, "Project list, Project lists"
: [
  "Lista do Projeto"
 ,"Listas de Projetos"

]
, "Project lists"
: "Listas de Projetos"

, "Quick Search"
: "Busca Rápida"

, "Description"
: "Descrição"

, "Last Modified Time"
: "Hora da última modificação"

, "Last Modified By"
: "Modificado por"

, "Creation Time"
: "Data de Criação"

, "Created By"
: "Criado por"

, "Attendee"
: "Participante"

, "Attendee Role"
: "Perfil do participante"

, "Please choose the Project to add the contacts to"
: "Selecione o Projeto onde serão adicionados os contatos"

, "Please select the attenders' role"
: "Selecione o perfil do participante"

, "Select Project"
: "Selecione o Projeto"

, "Role"
: "Perfil"

, "Select Role"
: "Selecione o Perfil"

, "Adding {0} Participants to project"
: "Adicionando {0} Participantes ao projeto"

, "Enter description"
: "Digitar a Descrição"

, "All my projects"
: "Todos os meus projetos"

, "Default Favorite"
: "Valor Padrão"

, "The default favorite which is loaded on Projects startup"
: "O favorito padrão que será carregado na inicialização dos Projetos"

, "Project Status Available"
: "Situação de Projeto Disponível"

, "Possible Project status. Please note that additional project status might impact other Projects systems on export or syncronisation."
: "Situação de Projeto Possível.  Favor observar que uma situação adicional de projeto pode afetar sistemas de outros Projetos durante a exportação ou sincronização."

, "On hold"
: "Aguardando"

, "Completed"
: "Completo"

, "Cancelled"
: "Cancelado"

, "In process"
: "Processando"

, "Project Attendee Role Available"
: "Perfil de Participante de Projeto Disponível"

, "Possible Project attendee roles. Please note that additional project attendee roles might impact other Projects systems on export or syncronisation."
: "Perfis de participantes de projetos possíveis. Favor observar que um perfil adicional de um participante do projeto pode afetar sistemas de outros Projetos durante a exportação ou sincronização."

, "Coworker"
: "Colega de trabalho"

, "Responsible"
: "Responsável"

, "%s's personal Projects"
: "%s's Projetos pessoais"

, "All my open projects"
: "Todos os meus projetos ativos"

, "My projects that I'm responsible for"
: "Projetos sob minha responsabilidade"

, "All my open projects that I am responsible for"
: "Todos os projetos abertos pelos quais sou responsável"

, "My waiting projects"
: "Meus projetos em espera"

, "My projects that are on hold"
: "Meus projetos que estão retidos"

, "Manage shared project favorites"
: "Gerenciar favoritos em projetos compartilhados"

, "Create new shared project favorites"
: "Criar novos favoritos em projetos compartilhados"

, "Project"
: "Projeto"

, "Project list"
: "Lista do Projeto"

}));
